Change Log
==========

v0.4.1
------

* Publish ZDD-backend version to PyPI.

v0.4.0
------

* Release ZDD-backend enumerator. An actual implementation with TdZdd are written in `pyzdd <https://github.com/lan496/pyzdd>`_.
* Add example notebooks for basic usage, composition constraints, and site constraints.

v0.3.15
-------

* First PyPI release
